@@ -358,7 +358,10 @@ void Account::setStatus(PurpleStatusPrimitive prim, string message)
 			chan->setTopic(NULL, message);
 	}
 
-	purple_account_set_status(account, id, TRUE, "message", message.c_str(), (char*)NULL);
+	char *utf8 = purple_utf8_try_convert(message.c_str());
+	purple_account_set_status(account, id, TRUE, "message", utf8, (char*)NULL);
+
+	g_free(utf8);
 }
 
 PurpleStatusPrimitive Account::getStatus() const
@@ -394,11 +397,11 @@ void Account::setID(string id) const
 	purple_account_set_ui_string(account, MINBIF_VERSION_NAME, "id", id.c_str());
 }
 
-string Account::getID() const
+string Account::getID(bool calculate_newone) const
 {
 	assert(isValid());
 	string n = purple_account_get_ui_string(account, MINBIF_VERSION_NAME, "id", "");
-	if(n.empty())
+	if(calculate_newone && n.empty())
 	{
 		n = Purple::getNewAccountName(proto, *this);
 		setID(n);
@@ -458,15 +461,18 @@ void Account::abortChannelJoins()
 {
 	assert(isValid());
 
-	irc::IRC* irc = Purple::getIM()->getIRC();
-	string list = purple_account_get_ui_string(account, MINBIF_VERSION_NAME, "join_queue", "");
-	string cname;
+	if (isConnected())
+	{
+		irc::IRC* irc = Purple::getIM()->getIRC();
+		string list = purple_account_get_ui_string(account, MINBIF_VERSION_NAME, "join_queue", "");
+		string cname;
 
-	while((cname = stringtok(list, ",")).empty() == false)
-		irc->getUser()->send(irc::Message(ERR_NOSUCHCHANNEL).setSender(irc)
-		                                                    .setReceiver(irc->getUser())
-		                                                    .addArg("#" + cname + ":" + getID())
-		                                                    .addArg("No such channel"));
+		while((cname = stringtok(list, ",")).empty() == false)
+			irc->getUser()->send(irc::Message(ERR_NOSUCHCHANNEL).setSender(irc)
+									    .setReceiver(irc->getUser())
+									    .addArg("#" + cname + ":" + getID())
+									    .addArg("No such channel"));
+	}
 
 	purple_account_set_ui_string(account, MINBIF_VERSION_NAME, "join_queue", "");
 
@@ -1223,13 +1229,16 @@ void Account::disconnected(PurpleConnection* gc)
 {
 	Account account = Account(gc->account);
 	GList* list = purple_get_chats();
+	GList* next = NULL;
 
 	account.abortChannelJoins();
 
 	/* Enqueue channels to auto-rejoin. */
-	for(; list; list = list->next)
+	for(; list; list = next)
 	{
 		Conversation c((PurpleConversation*)list->data);
+		next = list->next;
+
 		if(c.getAccount() != account)
 			continue;
 		if(purple_conv_chat_has_left(c.getPurpleChat()))
